@@ -22,42 +22,34 @@ vroom(file)
 vroom(file, delim = ",")
 
 ## -----------------------------------------------------------------------------
-mt <- tibble::rownames_to_column(mtcars, "model")
-purrr::iwalk(
-  split(mt, mt$cyl),
-  ~ vroom_write(.x, glue::glue("mtcars_{.y}.csv"), "\t")
-)
+ve <- grep("mtcars-[0-9].csv", vroom_examples(), value = TRUE)
+files <- sapply(ve, vroom_example)
+files
 
 ## -----------------------------------------------------------------------------
-files <- fs::dir_ls(glob = "mtcars*csv")
-files
 vroom(files)
 
 ## -----------------------------------------------------------------------------
 vroom(files, id = "path")
 
-## ---- include = FALSE---------------------------------------------------------
-# just to clear .Last.value
-1 + 1
-gc()
-unlink(files)
-
 ## -----------------------------------------------------------------------------
 file <- vroom_example("mtcars.csv.gz")
 
 vroom(file)
 
 ## -----------------------------------------------------------------------------
-read_all_zip <- function(file, ...) {
-  filenames <- unzip(file, list = TRUE)$Name
-  vroom(purrr::map(filenames, ~ unz(file, .x)), ...)
-}
+zip_file <- vroom_example("mtcars-multi-cyl.zip")
+filenames <- unzip(zip_file, list = TRUE)$Name
+filenames
 
-## ---- eval = as.logical(Sys.getenv("NOT_CRAN", "false"))----------------------
+# imagine we only want to read 2 of the 3 files
+vroom(purrr::map(filenames[c(1, 3)], ~ unz(zip_file, .x)))
+
+## ----eval = as.logical(Sys.getenv("NOT_CRAN", "false"))-----------------------
 #  file <- "https://raw.githubusercontent.com/tidyverse/vroom/main/inst/extdata/mtcars.csv"
 #  vroom(file)
 
-## ---- eval = as.logical(Sys.getenv("NOT_CRAN", "false"))----------------------
+## ----eval = as.logical(Sys.getenv("NOT_CRAN", "false"))-----------------------
 #  file <- "https://raw.githubusercontent.com/tidyverse/vroom/main/inst/extdata/mtcars.csv.gz"
 #  vroom(file)
 
@@ -119,7 +111,7 @@ vroom(
   col_types = list(gear = col_factor(levels = c(gear = c("3", "4", "5"))))
 )
 
-## ---- eval = FALSE------------------------------------------------------------
+## ----eval = FALSE-------------------------------------------------------------
 #  vroom(
 #    vroom_example("mtcars.csv"),
 #    .name_repair = ~ janitor::make_clean_names(., case = "all_caps")
@@ -128,13 +120,13 @@ vroom(
 ## -----------------------------------------------------------------------------
 vroom_write(mtcars, "mtcars.tsv")
 
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 unlink("mtcars.tsv")
 
 ## -----------------------------------------------------------------------------
 vroom_write(mtcars, "mtcars.csv", delim = ",")
 
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 unlink("mtcars.csv")
 
 ## -----------------------------------------------------------------------------
@@ -144,12 +136,12 @@ vroom_write(mtcars, "mtcars.tsv.bz2")
 
 vroom_write(mtcars, "mtcars.tsv.xz")
 
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 unlink(c("mtcars.tsv.gz", "mtcars.tsv.bz2", "mtcars.tsv.xz"))
 
-## ---- eval = nzchar(Sys.which("pigz"))----------------------------------------
+## ----eval = nzchar(Sys.which("pigz"))-----------------------------------------
 #  vroom_write(mtcars, pipe("pigz > mtcars.tsv.gz"))
 
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 unlink("mtcars.tsv.gz")
 
